/* ioctldef.h
 *
 * IOCTL Commands Def.
 *
 * this file is to be #include(d) in the program that calls the vw2010 driver.
 * It is also used internally by the driver - don't modify this unless you know what you are doing!!!!
 *
 * Vweb Corp.
 *
 * [09-20-2002]QW: First created.
 *
*/

#ifndef _IOCTL_CMDS_DEF_H_
#define _IOCTL_CMDS_DEF_H_

//#define VWEB_BIG_ENDIAN

#ifndef INI_STRUCT_DEFINED

#include "./types.h"


        typedef unsigned char     U8;
  typedef unsigned short     U16;
  typedef unsigned long     U32;

  #define BOARD_NO    0

  #define PRE_BUFFER    100000

  #ifndef FALSE
  #define FALSE       0
  #endif

  #ifndef TRUE
  #define TRUE       !FALSE
  #endif

    typedef enum {
      CONFIG_INT32 = 1,
      CONFIG_UINT32,
      CONFIG_STR,
      CONFIG_DOUBLE,
      CONFIG_INT64,
      CONFIG_HEX,
      CONFIG_INT16_ARRAY,
      CONFIG_INT32_ARRAY,
      CONFIG_BYTE_ARRAY,
      CONFIG_FLOAT
    } config_struct_types;      //parameter type

    typedef struct {
      int   Id;         //ID number of this parameter
      char  *Name;      //name of this parameter

      config_struct_types Type;

      union {
        int             value_int;      //parameter value;
        unsigned int    value_uint;
        char            *value_str;
        double          value_double;
        INT64           value_int64;
        unsigned int    value_hex;
        unsigned short  value_array16[2];   // short array used by gop
        int             *value_array32;
        BYTE            *value_array8;
        float      value_float;
      };

      int   Params;           // number of paramters
      int   Len;              // uses - strlen(value_str) OR array_size(value_ptr)
    } config_struct;


  typedef union
  {
    struct
    {
#ifdef VWEB_BIG_ENDIAN
      unsigned short  High;
      unsigned short  Low;
#else//Little Endian
      unsigned short  Low;
      unsigned short  High;
#endif
    } _16;
    unsigned int  _32;
  } Addr2Mem, *PAddr2Mem;

  #define MAX_PARAMS    256
  #define  YES      1
  #define NO      0

  typedef struct _QUERY_VW_DRIVER_VERSION
  {
    U32      VERSION;
  } QUERY_VW_DRIVER_VERSION, *PQUERY_VW_DRIVER_VERSION;

  #define SIZEOF_VW_DRIVER_VERSION sizeof(QUERY_VW_DRIVER_VERSION)

  typedef struct _ACCESS_VW_VDRAM
  {
    union {
      struct {
#ifdef VWEB_BIG_ENDIAN
        U16   High;
        U16   Low;
#else//Little Endian
        U16    Low;
        U16    High;
#endif
      } _16;
      U32    _32;
    } Addr;

    union {
      struct {
#ifdef VWEB_BIG_ENDIAN
        U16   High;
        U16   Low;
#else//Little Endian
        U16    Low;
        U16    High;
#endif
      } _16;
      U32    _32;
    } Data;

    union {
      struct {
#ifdef VWEB_BIG_ENDIAN
        U16   High;
        U16   Low;
#else//Little Endian
        U16    Low;
        U16    High;
#endif
      } _16;
      U32    _32;
    } ExtraData;  //new for vw2010; decoder memory
  } ACCESS_VW_VDRAM, *PACCESS_VW_VDRAM;

  #define SIZEOF_ACCESS_VW_VDRAM sizeof(ACCESS_VW_VDRAM)

  typedef struct _ACCESS_VW_REGS
  {
    U16 HIU_CMD;
    U16 VW_REG;
    U16 Data;
  } ACCESS_VW_REGS, *PACCESS_VW_REGS;

  #define SIZEOF_ACCESS_VW_REGS sizeof(ACCESS_VW_REGS)

  typedef struct _VW_HOST_CMD
  {
    union
    {
    struct
    {
#ifdef VWEB_BIG_ENDIAN
      U8     Ack;
      U8     Cmd;
#else//Little Endian
      U8    Cmd;
      U8    Ack;
#endif
    } _8;
    U16    _16;
    } Reg;
    Addr2Mem    Handle;
    U16      Have_Params;    //=0:No <>0:Yes
    Addr2Mem    Params[MAX_PARAMS];
  } VW_HOST_CMD, *PVW_HOST_CMD;

  #define SIZEOF_VW_HOST_CMD sizeof(VW_HOST_CMD)

  typedef struct _VW_CMD_BLOCK
  {
#ifdef VWEB_BIG_ENDIAN
    U8      ACK;
    U8      RESV[3];
#elif defined(_WIN32_WCE)
    U8      ACK;
#else
    U32      ACK;
#endif
    U32      Handle;
    U32      RCode;    //0=good; otherwise with a error code
    U32      ParamsLen;  //in words (4 bytes)
    U32      VWCmd;
    U32      Params[MAX_PARAMS];
  } VW_CMD_BLOCK, *PVW_CMD_BLOCK;

  #define SIZEOF_VW_CMD_BLOCK sizeof(VW_CMD_BLOCK)

  typedef struct _VW_RW_BLOCK  //only for Linux
  {
    U32      Handle;
    PVOID    buf;
    U32      buf_size;
  } VW_RW_BLOCK, *PVW_RW_BLOCK;

  #define SIZEOF_VW_RW_BLOCK sizeof(VW_RW_BLOCK)

  typedef enum __Host2VWCmd
  {
    FirstCmd=0,
    ReadCmd,
    IoctlCmd,
    WriteCmd,
    MallocCmd,
    FreeCmd,
    LastCmd          // do not add commands below this line
  } Host2VWCmd, *PHost2VWCmd;

  typedef struct _VW_OSD_DATA  //only for Linux
  {
    U16  *buf;
  } VW_OSD_DATA, *PVW_OSD_DATA;
  #define SIZEOF_VW_OSD_DATA sizeof(VW_OSD_DATA)

  //+v4.00
  typedef struct _USR_STREAM_DMA
  {
    U32  phyAddr;  // physical addresses
    PVOID  virtAddr;  // virtual address
    PVOID  kernAddr;  // kernel address   //+v4.01
    U32  BufSz;    // in bytes
    U32  Handle;
  } USR_STREAM_DMA, *PUSR_STREAM_DMA;
  #define SIZEOF_USR_STREAM_DMA sizeof(USR_STREAM_DMA)
  //-v4.00


  #ifdef WIN32
  //  Macro definition for IOCTL and FSCTL (function control codes).  Note
  //  that function codes 0-2047 are reserved for Microsoft Corporation,
  //  and 2048-4095 are reserved for customers.
    #define KEY_IOCTL_VW_INIT_CMD  0xA00
    #define KEY_IOCTL_VW_DEINIT_CMD  0xA01
    #define KEY_IOCTL_VW_READ    0xA02
    #define KEY_IOCTL_VW_WRITE    0xA03
    #define KEY_IOCTL_VW_IOCTL    0xA04
    #define KEY_IOCTL_VW_TIMER_ON  0xA05  //v1.13
    #define KEY_IOCTL_VW_TIMER_OFF  0xA06  //v1.13
    #define KEY_IOCTL_VW_VERSION    0xA0D
    #define KEY_IOCTL_VW_RD_DDRAM  0xA1A
    #define KEY_IOCTL_VW_WR_DDRAM  0xA1B
    #define KEY_IOCTL_VW_RD_EDRAM  0xA1E
    #define KEY_IOCTL_VW_WR_EDRAM  0xA1F
    #define KEY_IOCTL_VW_RD_REGS  0xA20
    #define KEY_IOCTL_VW_WR_REGS  0xA21
    #define KEY_IOCTL_VW_CLI      0xA22
    #define KEY_IOCTL_VW_STI      0xA23

    #define KEY_IOCTL_VW_RESET_HANDLES  0xA22  //v1.11
    #define KEY_IOCTL_VW_DOWNLOAD_OSD  0xA23  //v2.00
    #define KEY_IOCTL_VW_SET_XFER_PAGE  0xA24  //v2.01

    #define KEY_IOCTL_VW_DECODER_ONLY  0xA24  //arthur says replace the old one with this

    #define KEY_IOCTL_VW_RD_DDRAM32    0xA25
    #define KEY_IOCTL_VW_WR_DDRAM32    0xA26
    #define KEY_IOCTL_VW_IO_READ    0xA27
    #define KEY_IOCTL_VW_IO_WRITE    0xA28

    #define KEY_IOCTL_VW_ALLOC_KERN_MEM  0xA29  //v4.00
    #define KEY_IOCTL_VW_FREE_KERN_MEM  0xA2a  //v4.00
    #define KEY_IOCTL_VW_IOCTL_EX    0xA2b  //v4.00

    #define KEY_IOCTL_SET_CLK_135MHZ  0xA2c  //v5.03
    #define KEY_IOCTL_SET_CLK_162MHZ  0xA2d  //v5.03

    #define KEY_IOCTL_MAX_KEY           0xA2e
  #else
    #define KEY_IOCTL_VW_INIT_CMD  0x00
    #define KEY_IOCTL_VW_DEINIT_CMD  0x01
    #define KEY_IOCTL_VW_READ  0x02
    #define KEY_IOCTL_VW_WRITE  0x03
    #define KEY_IOCTL_VW_IOCTL  0x04
    #define KEY_IOCTL_VW_VERSION  0x0D
    #define KEY_IOCTL_VW_RD_DDRAM  0x1A
    #define KEY_IOCTL_VW_WR_DDRAM  0x1B
    #define KEY_IOCTL_VW_RD_EDRAM  0x1E
    #define KEY_IOCTL_VW_WR_EDRAM  0x1F
    #define KEY_IOCTL_VW_RD_REGS  0x20
    #define KEY_IOCTL_VW_WR_REGS  0x21
    #define KEY_IOCTL_VW_CLI  0x22
    #define KEY_IOCTL_VW_STI  0x23

    //+V2
    #define KEY_IOCTL_VW_RESET_HANDLES  0x24
    #define KEY_IOCTL_VW_SET_XFER_TIMEOUT  0x25
    #define KEY_IOCTL_VW_SET_XFER_PAGE  0x26
    #define KEY_IOCTL_VW_DOWNLOAD_OSD  0x27
    //-V2

  //+v2.3
    #define KEY_IOCTL_VW_DECODER_ONLY  0x28
    #define KEY_IOCTL_VW_RD_DDRAM32    0x29
    #define KEY_IOCTL_VW_WR_DDRAM32    0x30

    #define KEY_IOCTL_VW_IO_READ  0x2a
    #define KEY_IOCTL_VW_IO_WRITE  0x2b

    #define KEY_IOCTL_VW_ALLOC_KERN_MEM  0x2c  //V2.6
    #define KEY_IOCTL_VW_FREE_KERN_MEM  0x2d  //V2.6
    #define KEY_IOCTL_VW_IOCTL_EX    0x2e  //V2.6
    #define KEY_IOCTL_VW_SET_MMAP_HANDLE  0x2f  //V2.6
    //
    //  Always adjust this value when adding ioctl keys.
    //
    #define KEY_IOCTL_MAX_KEY  0x31
  #endif

  //
  //  Always adjust this value when adding ioctl keys.
  //

  #define UNIMPLEMENTED_IOCTL         0xDEADBEEF


  //
  //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  //

  /* Magic number used to uniqueify ioctl commands */
  static const unsigned char VW_MAGIC =  'v'|'w';

  #ifdef WIN32
    #define FILE_DEVICE_VWEB 0x00008300
    #define VW_IOCTL_SEND_CMD      CTL_CODE(FILE_DEVICE_VWEB, 0xA04, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #define VW_IOCTL_RD_DDRAM      CTL_CODE(FILE_DEVICE_VWEB, 0xA1A, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #define VW_IOCTL_WR_DDRAM      CTL_CODE(FILE_DEVICE_VWEB, 0xA1B, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #define VW_IOCTL_RD_EDRAM      CTL_CODE(FILE_DEVICE_VWEB, 0xA1E, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #define VW_IOCTL_WR_EDRAM      CTL_CODE(FILE_DEVICE_VWEB, 0xA1F, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #define VW_IOCTL_RD_REGS      CTL_CODE(FILE_DEVICE_VWEB, 0xA20, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #define VW_IOCTL_WR_REGS      CTL_CODE(FILE_DEVICE_VWEB, 0xA21, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #ifdef _WIN32_WCE
      #define VW_IOCTL_READ               CTL_CODE(FILE_DEVICE_VWEB, 0xA02, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_WRITE              CTL_CODE(FILE_DEVICE_VWEB, 0xA03, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_ALLOC_CMD_BLOCK    CTL_CODE(FILE_DEVICE_VWEB, 0xA23, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_FREE_CMD_BLOCK     CTL_CODE(FILE_DEVICE_VWEB, 0xA24, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_XFER_TIMEOUT   CTL_CODE(FILE_DEVICE_VWEB, 0xA25, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_XFER_PAGE      CTL_CODE(FILE_DEVICE_VWEB, UNIMPLEMENTED_IOCTL, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_DOWNLOAD_OSD       CTL_CODE(FILE_DEVICE_VWEB, 0xA27, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_IO_READ            CTL_CODE(FILE_DEVICE_VWEB, 0xA28, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_IO_WRITE           CTL_CODE(FILE_DEVICE_VWEB, 0xA29, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_ALLOC_KERN_MEM     CTL_CODE(FILE_DEVICE_VWEB, 0xA2A, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_FREE_KERN_MEM      CTL_CODE(FILE_DEVICE_VWEB, 0xA2B, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SEND_CMD_EX        CTL_CODE(FILE_DEVICE_VWEB, 0xA2C, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_CLK_135MHZ    CTL_CODE(FILE_DEVICE_VWEB, UNIMPLEMENTED_IOCTL, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_CLK_162MHZ    CTL_CODE(FILE_DEVICE_VWEB, UNIMPLEMENTED_IOCTL, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_RESET_HANDLES    CTL_CODE(FILE_DEVICE_VWEB, UNIMPLEMENTED_IOCTL, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_DRIVER_VERSION    CTL_CODE(FILE_DEVICE_VWEB, UNIMPLEMENTED_IOCTL, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #else
      #define VW_IOCTL_ALLOC_CMD_BLOCK    CTL_CODE(FILE_DEVICE_VWEB, 0xA00, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_FREE_CMD_BLOCK     CTL_CODE(FILE_DEVICE_VWEB, 0xA01, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_READ               CTL_CODE(FILE_DEVICE_VWEB, 0xA02, METHOD_OUT_DIRECT, FILE_ANY_ACCESS)
      #define VW_IOCTL_WRITE              CTL_CODE(FILE_DEVICE_VWEB, 0xA03, METHOD_IN_DIRECT, FILE_ANY_ACCESS)
      #define VW_IOCTL_DRIVER_VERSION    CTL_CODE(FILE_DEVICE_VWEB, 0xA0D, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_RESET_HANDLES    CTL_CODE(FILE_DEVICE_VWEB, 0xA22, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_DOWNLOAD_OSD       CTL_CODE(FILE_DEVICE_VWEB, 0xA23, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_DECODER_ONLY    CTL_CODE(FILE_DEVICE_VWEB, 0xA24, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_XFER_PAGE    CTL_CODE(FILE_DEVICE_VWEB, 0xA24, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_ALLOC_KERN_MEM     CTL_CODE(FILE_DEVICE_VWEB, 0xA29, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_FREE_KERN_MEM      CTL_CODE(FILE_DEVICE_VWEB, 0xA2A, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SEND_CMD_EX        CTL_CODE(FILE_DEVICE_VWEB, 0xA2B, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_CLK_135MHZ    CTL_CODE(FILE_DEVICE_VWEB, 0xA2c, METHOD_BUFFERED, FILE_ANY_ACCESS)
      #define VW_IOCTL_SET_CLK_162MHZ    CTL_CODE(FILE_DEVICE_VWEB, 0xA2d, METHOD_BUFFERED, FILE_ANY_ACCESS)
    #endif
  #else
    #define VW_IOCTL_SEND_CMD         _IOWR(VW_MAGIC, KEY_IOCTL_VW_IOCTL, VW_CMD_BLOCK)
    #define VW_IOCTL_ALLOC_CMD_BLOCK  _IOWR(VW_MAGIC, KEY_IOCTL_VW_INIT_CMD, unsigned long)
    #define VW_IOCTL_FREE_CMD_BLOCK   _IOWR(VW_MAGIC, KEY_IOCTL_VW_DEINIT_CMD, unsigned long)
    #define VW_IOCTL_WRITE            _IOWR(VW_MAGIC, KEY_IOCTL_VW_WRITE, VW_RW_BLOCK)
    #define VW_IOCTL_READ             _IOWR(VW_MAGIC, KEY_IOCTL_VW_READ, VW_RW_BLOCK)
    #define VW_IOCTL_DRIVER_VERSION   _IOWR(VW_MAGIC, KEY_IOCTL_VW_VERSION, QUERY_VW_DRIVER_VERSION)
    #define VW_IOCTL_RD_EDRAM         _IOWR(VW_MAGIC, KEY_IOCTL_VW_RD_EDRAM, ACCESS_VW_VDRAM)
    #define VW_IOCTL_WR_EDRAM         _IOWR(VW_MAGIC, KEY_IOCTL_VW_WR_EDRAM, ACCESS_VW_VDRAM)
    #define VW_IOCTL_RD_REGS          _IOWR(VW_MAGIC, KEY_IOCTL_VW_RD_REGS, ACCESS_VW_REGS)
    #define VW_IOCTL_WR_REGS          _IOWR(VW_MAGIC, KEY_IOCTL_VW_WR_REGS, ACCESS_VW_REGS)
    #define VW_IOCTL_RD_DDRAM         _IOWR(VW_MAGIC, KEY_IOCTL_VW_RD_DDRAM, ACCESS_VW_VDRAM)
    #define VW_IOCTL_WR_DDRAM         _IOWR(VW_MAGIC, KEY_IOCTL_VW_WR_DDRAM, ACCESS_VW_VDRAM)
    #define VW_IOCTL_CLI              _IO(VW_MAGIC, KEY_IOCTL_VW_CLI)
    #define VW_IOCTL_STI              _IO(VW_MAGIC, KEY_IOCTL_VW_STI)

    //+V2
    #define VW_IOCTL_RESET_HANDLES      _IO(VW_MAGIC, KEY_IOCTL_VW_RESET_HANDLES)
    #define VW_IOCTL_SET_XFER_TIMEOUT   _IOWR(VW_MAGIC, KEY_IOCTL_VW_SET_XFER_TIMEOUT, unsigned long)
    #define VW_IOCTL_SET_XFER_PAGE      _IOWR(VW_MAGIC, KEY_IOCTL_VW_SET_XFER_PAGE, unsigned long)
    #define VW_IOCTL_DOWNLOAD_OSD  _IOWR(VW_MAGIC, KEY_IOCTL_VW_DOWNLOAD_OSD, unsigned short *)
    //-V2

    //+v2.3
    #define VW_IOCTL_DECODER_ONLY  _IO(VW_MAGIC, KEY_IOCTL_VW_DECODER_ONLY)
    #define VW_IOCTL_RD_DDRAM32  _IOWR(VW_MAGIC, KEY_IOCTL_VW_RD_DDRAM32, ACCESS_VW_VDRAM)
    #define VW_IOCTL_WR_DDRAM32  _IOWR(VW_MAGIC, KEY_IOCTL_VW_WR_DDRAM32, ACCESS_VW_VDRAM)
    //-v2.3

    #define VW_IOCTL_IO_WRITE  _IOWR(VW_MAGIC, KEY_IOCTL_VW_IO_WRITE, VW_RW_BLOCK)
    #define VW_IOCTL_IO_READ  _IOWR(VW_MAGIC, KEY_IOCTL_VW_IO_READ, VW_RW_BLOCK)

    //+V2.6
    #define VW_IOCTL_ALLOC_KERN_MEM    _IOWR(VW_MAGIC, KEY_IOCTL_VW_ALLOC_KERN_MEM, USR_STREAM_DMA)
    #define VW_IOCTL_FREE_KERN_MEM    _IOW(VW_MAGIC, KEY_IOCTL_VW_FREE_KERN_MEM, unsigned long)
    #define VW_IOCTL_SEND_CMD_EX    _IOWR(VW_MAGIC, KEY_IOCTL_VW_IOCTL_EX, VW_CMD_BLOCK)
    #define VW_IOCTL_SET_MMAP_HANDLE  _IOW(VW_MAGIC, KEY_IOCTL_VW_SET_MMAP_HANDLE, unsigned long)
    //-V2.6
  #endif

  enum
  {
    STATE_START,
    STATE_TYPE,
    STATE_LEN,
    STATE_ADDR,
    STATE_DATA,
    STATE_CHKSUM,
    STATE_DONE,
  };

  //For Demux (maybe MUX too...)
  #define DEMUX_OK                    (0)
  #define DEMUX_FAILED                (-1)
  #define DEMUX_INVALID_PARAM         (-2)

  #define DEMUX_CTRL_GET_PARAM              0x00010000
  #define DEMUX_CTRL_SET_PARAM              0x00020000

  // .................... 1 parameter ......................
  #define DEMUX_PARAM_BYPASS_MODE           0x00000001
  #define DEMUX_PARAM_ACTIVE                0x00000002
  #define DEMUX_PARAM_INPUT_MODE            0x00000003
  #define DEMUX_PARAM_PMT_PID               0x00000004
  #define DEMUX_PARAM_NIT_PID               0x00000005
  #define DEMUX_PARAM_PRI_PID               0x00000006
  #define DEMUX_PARAM_FIFO_LEVEL            0x0000000A
  #define DEMUX_PARAM_ADAPT_FIELD           0x0000000B
  #define DEMUX_START                       0x0000000C
  #define DEMUX_STOP                        0x0000000D
  #define DEMUX_PARAM_PLAYBACK_PROGRAM      0x0000000E
  #define DEMUX_PARAM_NUM_OF_PROGRAM        0x0000000F
  #define DEMUX_PARAM_PCR_PID               0x00000010
  #define DEMUX_PARAM_IRQ_DELAY             0x00000011      //Demux irq delay in units of packets
  #define DEMUX_PARAM_ADAPT_W_OPTION        0x00000012      //option to write Adapt. packet to PSI buffer,
                                  //1 = write to PSI buffer, 0 = do not write
  #define DEMUX_PARAM_SERIAL_ENDIAN         0x00000013      //set serial endianess, MSB first or LSB first
  #define DEMUX_PARAM_SERIAL_MODE           0x00000014      //enable/disable serial port
  #define DEMUX_PARAM_DMA_R_PORT            0x00000015      //Select DEMUX dma destinatation, 0 for MIPS
  #define DEMUX_PARAM_DMA_W_PORT            0x00000016      //Select DEMUX dma destinatation, 0 for MIPS
  #define DEMUX_PARAM_RESET                 0x00000017
  #define DEMUX_PARAM_USER_PID_1            0x00000018
  #define DEMUX_PARAM_USER_PID_2            0x00000019
  #define DEMUX_PARAM_USER_PID_3            0x0000001A
  #define DEMUX_PARAM_USER_PID_MASK_1       0x0000001B
  #define DEMUX_PARAM_USER_PID_MASK_2       0x0000001C
  #define DEMUX_PARAM_USER_PID_MASK_3       0x0000001D
  #define DEMUX_PARAM_PCI_ENDIAN            0x0000001E      //set PCI endianess, 1 = Big Endian, 0 = Little Endian
  #define DEMUX_PARAM_BIT_RATE              0x0000001F
  #define DEMUX_PARAM_PREVIEW_MODE            0x00000020
  #define DEMUX_PARAM_AUTOMATIC_MODE          0x00000021      //cause demux to automatically demultiplex a program
  #define DEMUX_PARAM_AUDIO_1_PID             0x00000030
  #define DEMUX_PARAM_AUDIO_2_PID             0x00000031
  #define DEMUX_PARAM_AUDIO_3_PID             0x00000032
  #define DEMUX_PARAM_AUDIO_4_PID             0x00000033
  #define DEMUX_PARAM_VIDEO_1_PID             0x00000038
  #define DEMUX_PARAM_VIDEO_2_PID             0x00000039
  #define DEMUX_PARAM_VIDEO_3_PID             0x0000003a
  #define DEMUX_PARAM_VIDEO_4_PID             0x0000003b
  #define DEMUX_PARAM_AVSYNC_MODE        0x0000003c

  // ................... 2 parameters ......................
  #define DEMUX_PARAM_PSI_BUFFER            0x00000100
  #define DEMUX_PARAM_VIDEO_BUFFER          0x00000101
  #define DEMUX_PARAM_AUDIO1_BUFFER         0x00000102
  #define DEMUX_PARAM_AUDIO2_BUFFER         0x00000103
  #define DEMUX_PARAM_SYSTEM_BUFFER         0x00000104
  #define DEMUX_PARAM_PROGRAM_TABLE      0x00000105

  // ................... Demux input modes ..................
  #define DEMUX_INPUT_MODE_CDP              ((0<<10 | 0<<8 | 0<<7) >> 7)    //8 bit parallel compress data input
  #define DEMUX_INPUT_MODE_CDS              ((1<<10 | 0<<8 | 0<<7) >> 7)    //1-bit serial compress data input
  #define DEMUX_INPUT_MODE_PCI_SLAVE        ((0<<10 | 1<<8 | 0<<7) >> 7)    //PCI slave movde
  #define DEMUX_INPUT_MODE_PCI_MASTER       ((0<<10 | 1<<8 | 1<<7) >> 7)    //PCI master movde
  #define DEMUX_INPUT_MODE_HOST             ((0<<10 | 3<<8 | 0<<7) >> 7)    //Host mode
  #define DEMUX_INPUT_MODE_LOOP_BACK        ((0<<10 | 2<<8 | 0<<7) >> 7)    //Loop back mode

  ///////////////////////
  //// # D E F I N E S //
  ///////////////////////
  #define VW2010_ID              0
  #define VW2005_ID              2
  #define CHIP_ID_MASK           2
  #define SWAP_ENDIAN(x)        ( ((x>>24)&0xFF) | ((x>>8)&0xFF00) | ((x<<8)&0xFF0000) | (x<<24) )

  //+v4.00
  #define SYS_IOCTL_START_CIRCULAR_BUFFER_READ     0x01
  #define SYS_IOCTL_STOP_CIRCULAR_BUFFER_READ      0x02
  #define SYS_IOCTL_START_CIRCULAR_BUFFER_WRITE    0x03
  #define SYS_IOCTL_STOP_CIRCULAR_BUFFER_WRITE     0x04
  //-v4.00

  // pip ioctls
  #define PCI_COMM_SYS_IOCTL_PIP_ENABLE          0x1001
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_PLALETTE        0x1002
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_EVENFIELD0_ADDRESS  0x1003
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_EVENFIELD1_ADDRESS  0x1005
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_ODDFIELD0_ADDRESS  0x1004
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_ODDFIELD1_ADDRESS  0x1006
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_TERMINATE_ADDRESS  0x1007
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_X            0x1008
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_Y          0x1009
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_MIX_A         0x1010

  #define PCI_COMM_SYS_IOCTL_PIP_OSD_PALETTE        0X1011
  #define PCI_COMM_SYS_IOCTL_PIP_ENCODER_WIDTH_HEIGHT     0X1012
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_VIDEO_FORMAT         0X1013
  #define PCI_COMM_SYS_IOCTL_PIP_OSD_DOWNSIMPLING_RATE    0X1014
  #define PCI_COMM_SYS_IOCTL_PIP_FRAME_RATE               0X1015
  #define PCI_COMM_SYS_IOCTL_PIP_TOTAL_BAD_FRAME          0X1016
  #define PCI_COMM_SYS_IOCTL_PIP_UPDATE_PARAMTERS         0X1017
#endif


#endif  // #ifdefine _IOCTL_CMDS_DEF_H_
